==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebCalendarDateEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CalendarDateDescriptionMetadata } from "./CalendarDateDescriptionMetadata";
import { WebCalendarDateEventArgsDescription } from "./WebCalendarDateEventArgsDescription";
/**
 * @hidden
 */
export let WebCalendarDateEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCalendarDateEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebCalendarDateEventArgsDescriptionMetadata.a == null) {
                WebCalendarDateEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCalendarDateEventArgsDescriptionMetadata.c(WebCalendarDateEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebCalendarDateEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebCalendarDateEventArgsDescriptionMetadata.a);
            CalendarDateDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CalendarDateEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Detail", "ExportedType:CalendarDate");
        }
        static d(a) {
            WebCalendarDateEventArgsDescriptionMetadata.b(a);
            a.ad("WebCalendarDateEventArgs", () => new WebCalendarDateEventArgsDescription());
            a.ac("WebCalendarDateEventArgs", WebCalendarDateEventArgsDescriptionMetadata.a);
        }
    }
    WebCalendarDateEventArgsDescriptionMetadata.$t = markType(WebCalendarDateEventArgsDescriptionMetadata, 'WebCalendarDateEventArgsDescriptionMetadata');
    WebCalendarDateEventArgsDescriptionMetadata.a = null;
    return WebCalendarDateEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebCalendarDateEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CalendarDateDescriptionMetadata } from "./CalendarDateDescriptionMetadata";
import { WebCalendarDateEventArgsDescription } from "./WebCalendarDateEventArgsDescription";
/**
 * @hidden
 */
export let WebCalendarDateEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCalendarDateEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebCalendarDateEventArgsDescriptionMetadata.a == null) {
                WebCalendarDateEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCalendarDateEventArgsDescriptionMetadata.c(WebCalendarDateEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebCalendarDateEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebCalendarDateEventArgsDescriptionMetadata.a);
            CalendarDateDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CalendarDateEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Detail", "ExportedType:CalendarDate");
        }
        static d(a) {
            WebCalendarDateEventArgsDescriptionMetadata.b(a);
            a.ae("WebCalendarDateEventArgs", () => new WebCalendarDateEventArgsDescription());
            a.ad("WebCalendarDateEventArgs", WebCalendarDateEventArgsDescriptionMetadata.a);
        }
    }
    WebCalendarDateEventArgsDescriptionMetadata.$t = markType(WebCalendarDateEventArgsDescriptionMetadata, 'WebCalendarDateEventArgsDescriptionMetadata');
    WebCalendarDateEventArgsDescriptionMetadata.a = null;
    return WebCalendarDateEventArgsDescriptionMetadata;
})();
